@@ -19,7 +19,6 @@ class that must be used if a developer wishes to create a custom fusion
 algorithm for use within Pyrea.
 """
 import numpy as np
-import scipy
 from sklearn.cluster import AgglomerativeClustering, SpectralClustering, DBSCAN, OPTICS
 from typing import List, Union, Any
 from scipy.cluster import hierarchy
@@ -77,9 +76,17 @@ class HierarchicalClusteringPyrea(Clusterer):
 
         if self.precomputed:
             y = spatial.distance.squareform(data)
+
+            if self.method == 'ward2':
+                y = y**2
+
             tree = hierarchy.linkage(y, method=self.method, metric=self.metric)
         else:
             y = spatial.distance.pdist(data, metric=self.distance_metric, out=self.out)
+
+            if self.method == 'ward2':
+                y = y**2
+
             tree = hierarchy.linkage(y, method=self.method, metric=self.metric)
 
         return hierarchy.cut_tree(tree, n_clusters=self.n_clusters, height=self.height)
@@ -138,7 +145,10 @@ class SpectralClusteringPyrea(Clusterer):
                        coef0=1,
                        kernel_params=None,
                        n_jobs=None,
-                       verbose=False) -> None:
+                       verbose=False,
+                       method=None) -> None:  # method is not used, but is here
+                                              # for compatibility with other
+                                              # clustering algorithms
         """
         Perform spectral clustering.
 
@@ -187,7 +197,12 @@ class DBSCANPyrea(Clusterer):
                        algorithm='auto',
                        leaf_size=30,
                        p=None,
-                       n_jobs=None) -> None:
+                       n_jobs=None,
+                       n_clusters=None,
+                       method=None, # n_clusters and method are not used,
+                                    # but are here for compatibility with other
+                                    # clustering algorithms
+                       ) -> None:
         super().__init__()
 
         self.eps = eps
@@ -224,7 +239,12 @@ class OPTICSPyrea(Clusterer):
                        algorithm='auto',
                        leaf_size=30,
                        # memory=None,
-                       n_jobs=None) -> None:
+                       n_jobs=None,
+                       n_clusters=None,
+                       method=None) -> None:  # n_clusters and method are not
+                                              # used, but are here for
+                                              # compatibility with other
+                                              # clustering algorithms
         super().__init__()
         self.max_eps = max_eps
         self.min_samples = min_samples
@@ -451,22 +471,19 @@ class View(object):
     """
     def __init__(self, data, clusterer: List[Clusterer]) -> None:
 
-        self.data = np.asmatrix(data)
+        self.data = np.asarray(data)
         self.clusterer = clusterer
         self.labels = None
-        self.precomputed = None
 
-        # Numpy matrices can have max 2 dimensions, but can have 1 dimension.
-        # If this needs to be checked revert to above below.
-        #if data.ndim != 2:
-        #    raise Exception("Number of dimensions is not 2: you supplied a data structure with %s dimensions." % data.ndim)
+        if data.ndim != 2:
+            raise Exception("Number of dimensions is not 2: you supplied a data structure with %s dimensions." % data.ndim)
 
     def execute(self) -> list:
         """
         Clusters the :attr:`data` using the :attr:`clusterer` specified at
         initialisation.
         """
-        # TODO: check the types here, do we expect a list of clusterers? Or one?
+        # TODO: If a list is passed, then we need to execute them all.
         self.labels = self.clusterer.execute(self.data)
 
         return self.labels
